@@ -48,3 +48,33 @@ enve.truncate <- function
   y <- sort(x)[ -c(seq(1, n), seq(length(x)+1-n, length(x))) ]
   return(FUN(y))
 }
+
+#' Enveomics: Selection vector
+#' 
+#' Normalizes a selection vector \code{sel} to a logical vector with indexes
+#' from \code{dim.names}.
+#'
+#' @param sel A vector of numbers, characters, or booleans.
+#' @param dim.names A vector of names from which to select.
+#' 
+#' @return Returns a logical vector with the same length as \code{dim.name}.
+#' 
+#' @author Luis M. Rodriguez-R [aut, cre]
+#'
+#' @export
+
+enve.selvector <- function(sel, dim.names) {
+  if(is.logical(sel)) {
+    if(length(sel) != length(dim.names))
+      stop('sel is logical but differs in length from dim.names')
+    sel
+  } else if(is.numeric(sel)) {
+    if(max(sel) > length(dim.names))
+      stop('sel includes numeric index beyond the length of dim.names')
+    1:length(dim.names) %in% sel
+  } else {
+    if(any(!sel %in% dim.names))
+      stop('sel includes character index missing from dim.names')
+    dim.names %in% sel
+  }
+}
